#define MiX_TEXT_CPP_

#include "Text.h"

namespace MiX{
  //dmy_itcreateőOȗ邽߂̃gbN
  template <class charT,class char_traits,class xml_traits>
  const typename NodeList<charT,char_traits,xml_traits>::iterator Text<charT,char_traits,xml_traits>::dmy_it = NodeList<charT,char_traits,xml_traits>::iterator();
  
  template <class charT,class char_traits,class xml_traits>
  XMLString<charT,char_traits,xml_traits> Text<charT,char_traits,xml_traits>::toString(bool is_indent,const string_type& idt,int indent_off)const{
    std::basic_stringstream<charT,char_traits> ss;
    ss << ( is_indent ? make_indent(indent_off,idt) : string_type() )
       << getValue();
    if( is_indent ) ss << xml_traits::crlf();
    return ss.str();
  }

  
  template <class charT,class char_traits,class xml_traits>
  Text<charT,char_traits,xml_traits>& Text<charT,char_traits,xml_traits>::create(const string_type& str,element_type& parent,const typename nodelist_type::iterator& it){
    this_type* newtxt = new this_type(str);
    newtxt->setParent(parent);
    if(&it==&dmy_it) parent.getChildren().insert(parent.getChildren().end(),newtxt);
    else parent.getChildren().insert(it,newtxt);
    return *newtxt;
  }
  
}
